peewee_mssqlserv
################
.. image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat 
        :target: https://opensource.org/licenses/MIT 
.. image:: https://badge.fury.io/gh/brake%2Fpeewee_mssql.svg
        :target: https://badge.fury.io/gh/brake%2Fpeewee_mssql
.. image:: https://img.shields.io/badge/Python-2.7-red.svg

MS SQL Support for `peewee <https://github.com/coleifer/peewee>`_, lightweight Python ORM.
Based on `pyodbc <https://code.google.com/p/pyodbc/>`_.

Inspired by `this <https://github.com/coleifer/peewee/issues/122>`_ post.

At this moment it's in initial stage and supports `CRUD <https://en.wikipedia.org/wiki/Create,_read,_update_and_delete>`_ operations. 

May be it has more features, but I have not tested them yet.

For now only tested with python 2.7 and MS SQL Server 2008.

Installation
^^^^^^^^^^^^ 
.. code-block:: 

   pip install peewee_mssqlserv

Known alternative
^^^^^^^^^^^^^^^^^
(with declared python3 support): `peewee-mssql <https://pypi.python.org/pypi/peewee-mssql>`_ 

